@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : REM
-Version : 1.0.8
+Version : 1.0.10
 Author  : Stefano Covino
-Date    : 29/08/2012
+Date    : 22/03/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -22,9 +22,15 @@ History : (16/12/2011) First version.
         : (01/08/2012) V. 1.2.1b1.
         : (22/08/2012) V. 1.3.0b1.
         : (29/08/2012) V. 1.3.0.
+        : (31/08/2012) V. 1.3.1b1.
+        : (22/03/2013) V. 1.3.1.
 """
 
-__version__ = '1.3.0'
+__version__ = '1.3.1'
+
+
+
+__all__ =  ['GetObj', 'GetREMSite']
 
 
 
@@ -41,3 +47,10 @@ CAMERA  =   'INSTRUME'
 # External commands
 astro   =   'SRPAstrometry'
 
+# Observatory location
+REMLAT = '-29.2567'
+REMLONG = '-70.7292'
+REMHEIGHT = 2347.0
+
+
+
